#'Calculate sample size based on simple random sampling for estimating population average.
#'
#'srs.mean function calculates sample size based on simple random sampling for estimating population average.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return The required sample size given the inputs to the function
#'
#'@examples x=srs.mean(1000, 250000, 60, 0.05)
#'
#'@export
srs.mean=function(N, var, e, alpha){
  if(var<=0 || e<=0){
    stop("Variance =>0, Effect size =>0")
  }
  else{
    z=qnorm(1-(alpha/2))
    h=(N*(z^2)*(var))/((N*(e^2))+((z^2)*(var)))
    n=ceiling(h)
    cat("Simple random sampling for estimating average", "\n", "\n")
    cat("Sample size =", n, "\n")
    result=list(Samplesize= n)
    return(result)
  }
}

#'Calculate sample size based on simple random sampling for estimating population total.
#'
#'srs.total function calculates sample size based on simple random sampling for estimating population total.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return The required sample size given the inputs to the function
#'
#'@examples x=srs.total(45000, 160000, 800000, 0.05)
#'
#'@export
srs.total=function(N, var, e, alpha){
  if(var<=0 || e<=0){
    stop("Variance =>0, Effect size =>0")
  }
  else{
    z=qnorm(1-(alpha/2))
    h=((z^2)*(N^2)*(var))/((e^2)+((z^2)*N*var))
    n=ceiling(h)
    cat("Simple random sampling for estimating population total", "\n", "\n")
    cat("Sample size =", n, "\n")
    result=list(Samplesize= n)
    return(result)
  }
}

#'Calculate sample size based on simple random sampling for estimating population proportional.
#'
#'srs.prop function calculates sample size based on simple random sampling for estimating population proportional.
#'
#'@param N Total population.
#'@param p Population proportion or proportion obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return The required sample size given the inputs to the function
#'
#'@examples x=srs.prop(4000, 0.6, 0.05, 0.01)
#'
#'@export
srs.prop=function(N, p, e, alpha){
  if(p<=0 || e<=0){
    stop("Proportion => 0, Effect size =>0")
  }
  else{
    z=qnorm(1-(alpha/2))
    q=1-p
    h=(N*(z^2)*p*q)/((N*(e^2))+((z^2)*p*q))
    n=ceiling(h)
    cat("Simple random sampling or systematic for estimating proportional", "\n", "\n")
    cat("Sample size =", n, "\n")
    result=list(Samplesize= n)
    return(result)
  }
}

#'Calculate sample size based on systematic sampling for estimating population average.
#'
#'sys.mean function calculates sample size based on systematic sampling for estimating population average. After you got sample size then go to the calculates the k value and follow systematic sampling technique.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return The required sample size given the inputs to the function
#'
#'@examples x=sys.mean(1000, 250000, 60, 0.05)
#'
#'@export
sys.mean=function(N, var, e, alpha){
  if(var<=0 || e<=0){
    stop("Variance =>0, Effect size =>0")
  }
  else{
    z=qnorm(1-(alpha/2))
    h=(N*(z^2)*(var))/((N*(e^2))+((z^2)*(var)))
    n=ceiling(h)
    cat("Systematic sampling for estimating average", "\n", "\n")
    cat("Sample size =", n, "\n")
    result=list(Samplesize= n)
    return(result)
  }
}

#'Calculate sample size based on systematic sampling for estimating population total.
#'
#'sys.total function calculates sample size based on systematic sampling for estimating population total. After you got sample size then go to the calculates the k value and follow systematic sampling technique.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return The required sample size given the inputs to the function
#'
#'@examples x=sys.total(45000, 160000, 800000, 0.05)
#'
#'@export
sys.total=function(N, var, e, alpha){
  if(var<=0 || e<=0){
    stop("Variance =>0, Effect size =>0")
  }
  else{
    z=qnorm(1-(alpha/2))
    h=((z^2)*(N^2)*(var))/((e^2)+((z^2)*N*var))
    n=ceiling(h)
    cat("Systematic sampling for estimating population total", "\n", "\n")
    cat("Sample size =", n, "\n")
    result=list(Samplesize= n)
    return(result)
  }
}

#'Calculate sample size based on systematic sampling for estimating population proportional.
#'
#'sys.prop function calculates sample size based on systematic sampling for estimating population proportional. After you got sample size then go to the calculates the k value and follow systematic sampling technique.
#'
#'@param N Total population.
#'@param p Population proportion or proportion obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return The required sample size given the inputs to the function
#'
#'@examples x=sys.prop(4000, 0.6, 0.05, 0.01)
#'
#'@export
sys.prop=function(N, p, e, alpha){
  if(p<=0 || e<=0){
    stop("Proportion => 0, Effect size =>0")
  }
  else{
    z=qnorm(1-(alpha/2))
    q=1-p
    h=(N*(z^2)*p*q)/((N*(e^2))+((z^2)*p*q))
    n=ceiling(h)
    cat("Systematic sampling for estimating proportional", "\n", "\n")
    cat("Sample size =", n, "\n")
    result=list(Samplesize= n)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and equal allocaton for estimating average.
#'
#'stra.me function calculates sample size based on stratified sampling and equal allocaton for estimating average.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param L Number of stratum.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(600, 300, 100)
#'@examples # Vector of variance
#'@examples var=c(400, 900, 2500)
#'@examples # Calculate sample size
#'@examples x=stra.me(N, var, 3, 3, 0.0027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.me=function(N, var, L, e, alpha){
  if(any(var<=0) || e<=0 || L<=0){
    stop("Variance >=0, Effect size >=0", "L>=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    a=(N^2)*var
    b=N*var
    n=(L*sum(a))/(((NN^2)*E_sq)+sum(b))
    h=n/L
    nh=ceiling(h)
    total=sum(nh)*L
    Nh=N
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating average", "\n")
    cat("- Equal allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and proportional allocaton for estimating average.
#'
#'stra.mp function calculates sample size based on stratified sampling and proportional allocaton for estimating average.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(120, 160, 240)
#'@examples # Vector of variance
#'@examples var=c(400, 900, 2500)
#'@examples # Calculate sample size
#'@examples x=stra.mp(N, var, 3, 0.0027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.mp=function(N, var, e, alpha){
  if(any(var<=0) || e<=0){
    stop("Variance >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    a=N*var
    n=(NN*sum(a))/(((NN^2)*E_sq)+sum(a))
    h=(N*n)/NN
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating average", "\n","- Proportional allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and optimum allocaton for estimating average.
#'
#'stra.mo function calculates sample size based on stratified sampling and optimum allocaton for estimating average.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param c Unit cost.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(600, 300, 100)
#'@examples # Vector of variance
#'@examples var=c(400, 900, 2500)
#'@examples # Vector of unit cost
#'@examples c=c(25, 30, 44)
#'@examples # Calculate sample size
#'@examples x=stra.mo(N, var, c, 3, 0.0027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.mo=function(N, var, c, e, alpha){
  if(any(var<=0) || e<=0){
    stop("Variance >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    s=sqrt(var)
    a=N*s*sqrt(c)
    b=(N*s)/sqrt(c)
    d=N*var
    n=(sum(a)*sum(b))/(((NN^2)*E_sq)+sum(d))
    h=(n*b)/sum(b)
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, c, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating average", "\n","- Optimum allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and neyman allocaton for estimating average.
#'
#'stra.mny function calculates sample size based on stratified sampling and neyman allocaton for estimating average.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(600, 300, 100)
#'@examples # Vector of variance
#'@examples var=c(400, 900, 2500)
#'@examples # Calculate sample size
#'@examples x=stra.mny(N, var, 3, 0.0027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.mny=function(N, var, e, alpha){
  if(any(var<=0) || e<=0){
    stop("Variance >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    s=sqrt(var)
    a=N*s
    b=N*var
    g=sum(a)^2
    f=((NN^2)*E_sq)+sum(b)
    n=g/f
    h=(n*a)/sum(a)
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating average", "\n","- Neyman allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and equal allocaton for estimating proportion.
#'
#'stra.pe function calculates sample size based on stratified sampling and equal allocaton for estimating proportion.
#'
#'@param N Total population.
#'@param p Population proportion or proportion obtained from pilot study.
#'@param L Number of stratum.
#'@param e effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(2000,3000,4000)
#'@examples # Vector of proportion
#'@examples p=c(0.10, 0.15, 0.20)
#'@examples # Calculate sample size
#'@examples x=stra.pe(N, p, 3, 0.03, 0.027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.pe=function(N, p, L, e, alpha){
  if(any(p<=0) || e<=0 || L<=0){
    stop("proportion >=0, Effect size >=0", "L>=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    q=1-p
    NN=sum(N)
    a=(N/NN)^2
    b=p*q
    f=b/(N-1)
    h=a*b
    g=a*f
    n=((L/E_sq)*sum(h))/(1+((1/E_sq)*sum(g)))
    h=n/L
    nh=ceiling(h)
    total=sum(nh)*L
    Nh=N
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating proportional", "\n")
    cat("- Equal allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and proportional allocaton for estimating proportion.
#'
#'stra.pp function calculates sample size based on stratified sampling and proportional allocaton for estimating proportion.
#'
#'@param N Total population.
#'@param p Population proportion or proportion obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(2000,3000,5000)
#'@examples # Vector of proportion
#'@examples p=c(0.10, 0.15, 0.20)
#'@examples # Calculate sample size
#'@examples x=stra.pp(N, p, 0.03, 0.027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.pp=function(N, p, e, alpha){
  if(any(p<=0) || e<=0){
    stop("Proportion >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    q=1-p
    NN=sum(N)
    a=N*p*q
    m=((NN^2)*E_sq)+sum(a)
    n=(NN*sum(a))/m
    h=(N*n)/NN
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating proportion", "\n","- Proportional allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and optimum allocaton for estimating proportion.
#'
#'stra.po function calculates sample size based on stratified sampling and optimum allocaton for estimating proportion.
#'
#'@param N Total population.
#'@param p Population proportion or proportion obtained from pilot study.
#'@param c Unit cost.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(2000,3000,4000)
#'@examples # Vector of proportion
#'@examples p=c(0.10, 0.15, 0.20)
#'@examples # Vector of unit cost
#'@examples c=c(25, 30, 44)
#'@examples # Calculate sample size
#'@examples x=stra.po(N, p, c, 0.03, 0.027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.po=function(N, p, c, e, alpha){
  if(any(p<=0) || e<=0){
    stop("Proportion >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    q=1-p
    NN=sum(N)
    a=N*sqrt(p*q*c)
    b=N*sqrt((p*q)/c)
    f=N*p*q
    n=(sum(a)*sum(b))/(((NN^2)*E_sq)+sum(f))
    h=(n*b)/sum(b)
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, c, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating proportion", "\n","- Optimum allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and neyman allocaton for estimating proportion.
#'
#'stra.pny function calculates sample size based on stratified sampling and neyman allocaton for estimating proportion.
#'
#'@param N Total population.
#'@param p Population proportion or proportion obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(2000,3000,4000)
#'@examples # Vector of proportion
#'@examples p=c(0.10, 0.15, 0.20)
#'@examples # Calculate sample size
#'@examples x=stra.pny(N, p, 0.03, 0.027)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.pny=function(N, p, e, alpha){
  if(any(p<=0) || e<=0){
    stop("Proportion >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    q=1-p
    NN=sum(N)
    a=N*sqrt(p*q)
    b=N*p*q
    n=(sum(a))^2/(((NN^2)*E_sq)+sum(b))
    h=(n*a)/sum(a)
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating proportion", "\n","- Neyman allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and equal allocaton for estimating population total.
#'
#'stra.te function calculates sample size based on stratified sampling and equal allocaton for estimating population total.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param L Number of stratum.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(120, 160, 240)
#'@examples # Vector of variance
#'@examples var=c(441, 225, 100)
#'@examples # Calculate sample size
#'@examples x=stra.te(N, var, 3, 600, 0.05)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.te=function(N, var, L, e, alpha){
  if(any(var<=0) || e<=0 || L<=0){
    stop("Variance >=0, Effect size >=0", "L>=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    a=(N^2)*var
    b=N*var
    n=(L*sum(a))/(E_sq+sum(b))
    h=n/L
    nh=ceiling(h)
    total=sum(nh)*L
    Nh=N
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating population total", "\n")
    cat("- Equal allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and proprotional allocaton for estimating population total.
#'
#'stra.tp function calculates sample size based on stratified sampling and proprotional allocaton for estimating population total.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(120, 160, 240)
#'@examples # Vector of variance
#'@examples var=c(441, 225, 100)
#'@examples # Calculate sample size
#'@examples x=stra.tp(N, var, 600, 0.05)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.tp=function(N, var, e, alpha){
  if(any(var<=0) || e<=0){
    stop("Variance >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    a=N*var
    n=(NN*sum(a))/(E_sq+sum(a))
    h=(N*n)/NN
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating population total", "\n","- Proportional allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and optimum allocaton for estimating population total.
#'
#'stra.to function calculates sample size based on stratified sampling and optimum allocaton for estimating population total.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param c Unit cost.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(120, 160, 240)
#'@examples # Vector of variance
#'@examples var=c(441, 225, 100)
#'@examples # Vector of unit cost
#'@examples c=c(25, 30, 44)
#'@examples # Calculate sample size
#'@examples x=stra.to(N, var, c, 600, 0.05)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.to=function(N, var, c, e, alpha){
  if(any(var<=0) || e<=0){
    stop("Variance >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    s=sqrt(var)
    a=N*var
    f=N*s*sqrt(c)
    g=(N*s)/sqrt(c)
    n=(sum(f)*sum(g))/(E_sq+sum(a))
    h=(n*g)/sum(g)
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, c, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating population total", "\n","- Optimum allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

#'Calculate sample size based on stratified sampling and neyman allocaton for estimating population total.
#'
#'stra.tny function calculates sample size based on stratified sampling and neyman allocaton for estimating population total.
#'
#'@param N Total population.
#'@param var Population variance or variance obtained from pilot study.
#'@param e Effect size.
#'@param alpha Level of Significant.
#'
#'@return n the total sample size which does not rounding up the decimal.
#'@return Nh the population sizes, i.e. the number of units in each stratum.
#'@return nh the sample sizes in each stratum.
#'@return total the summary of nh.
#'
#'@examples # Vector of population total
#'@examples N=c(120, 160, 240)
#'@examples # Vector of variance
#'@examples var=c(441, 225, 100)
#'@examples # Calculate sample size
#'@examples x=stra.tny(N, var, 600, 0.05)
#'@examples # Data retrieval of nh
#'@examples x$nh
#'
#'@export
stra.tny=function(N, var, e, alpha){
  if(any(var<=0) || e<=0){
    stop("Variance >=0, Effect size >=0")
  }
  else{
    E_sq=(e^2)/(qnorm(1-(alpha/2))^2)
    NN=sum(N)
    s=sqrt(var)
    a=N*var
    b=N*s
    n=(sum(b)^2)/(E_sq+sum(a))
    h=(n*b)/sum(b)
    nh=ceiling(h)
    Nh=N
    total=sum(nh)
    frame=cbind(Nh, nh)
    rownames(frame)=rownames(frame, do.NULL = F, prefix = "stratum ")
    cat("Stratified sampling for estimating population total", "\n","- Neyman allcation ", "\n" )
    cat("n =",n, "\n", "\n")
    print(frame)
    cat("\n")
    cat("Total sample size:", total, "\n")
    result=list(n=n, nh=nh, Total=total)
    return(result)
  }
}

